#!/usr/bin/perl

# P*Wcal installer
# by Joel Savignon

use strict;

my $force = 0;
if ($ARGV[0] eq "-f")
{
    $force = 1;
}

# Test perl modules
eval("use PDA::Pilot");
if ($@)
{
    print "------------------------------------------------------------\n";
    print "Wcal requires module PDA::Pilot from the pilot-link package.\n";
    print "This comes with Wcal, please install it.\n";
    print "After installing the pilot-link package goto the.\n";
    print "tools/Perl5 subdirectory and run:.\n";
    print "> perl Makefile.PL\n";
    print "> make\n";
    print "> make install\n";
    print "Install canceled\n";
    exit 3;
}

my $wcalddir = "/usr/local/bin";
print "P*Wcal installer\n";
print "Please select the location of your wcald file\n";
print "($wcalddir) : ";
my $dir = <STDIN>;
chomp($dir);
if ($dir)
{
    $wcalddir = $dir;
}

if (!-e "$wcalddir/wcald")
{
    print "\n*** No $wcalddir/wcald file! ***\n";
    print "Install canceled\n";
    exit 1;
}

my ($wcalddev,$wcaldino,$wcaldmode,$wcaldnlink,$wcalduid,$wcaldgid) = stat("$wcalddir/wcald");
my $line;
if (!open(WCALD, "$wcalddir/wcald"))
{
    print "\n*** Unable to open $wcalddir/wcald file! ***\n";
    print "Install canceled\n";
    exit 2;
}
my $wcaldvers;
my $wcaldconfdir;
my $wcaldhttpdir;
my $wcalddbdir;
$wcaldmode = $wcaldmode & 0777;

print "wcal uid : $wcalduid\n";
print "wcal gid : $wcaldgid\n";
printf "wcal mod : %o\n", $wcaldmode;

while ($line = <WCALD>)
{
    if ($line =~ /^\$::VERSION\s*=\s*\"([^\"]*)/)
    {
	$wcaldvers = $1+0;
	print "wcal ver : $wcaldvers\n";
    }
    elsif ($line =~ /^\$::CONF_FILE\s*=\s*\'([^\']*)\/wcal.conf/)
    {
	$wcaldconfdir = $1;
	print "conf dir : $wcaldconfdir\n";
    }
    elsif ($line =~ /^\$::DIRECTORY\s*=\s*\'([^\']*)/)
    {
	$wcaldhttpdir = $1;
	print "http dir : $wcaldhttpdir\n";
    }
    elsif ($line =~ /^\$::DB_DIR\s*=\s*\'([^\']*)/)
    {
	$wcalddbdir = $1;
	print "data dir : $wcalddbdir\n";
    }
}
close(WCALD);

if (!$force && $wcaldvers < 2.2)
{
    print "\n*** Current version ($wcaldvers) of wcal must be at least 2.2 ***\n";
    print "Install canceled\n";
    exit 3;
}

print ("Copying pwcald\n");
open(PWCALD2, ">$wcalddir/pwcald");
open(PWCALD, "pwcald.in");
while ($line = <PWCALD>)
{
    $line =~ s/_X_CONF/$wcaldconfdir/g;
    $line =~ s/_X_DATA/$wcalddbdir/g;
    print PWCALD2 $line;
}
close(PWCALD);
close(PWCALD2);
chown($wcalduid, $wcaldgid, "$wcalddir/pwcald");
chmod($wcaldmode, "$wcalddir/pwcald");

print ("Copying pwcal.msg\n");
($wcalddev,$wcaldino,$wcaldmode,$wcaldnlink,$wcalduid,$wcaldgid) = stat("$wcaldconfdir/wcal.msg");
system("cp pwcal.msg $wcaldconfdir/pwcal.msg");
chown($wcalduid, $wcaldgid, "$wcaldconfdir/pwcal.msg");
chmod($wcaldmode, "$wcaldconfdir/pwcal.msg");

if (!-e "$wcaldconfdir/pwcal.conf")
{
    print ("Copying pwcal.conf\n");
    system("cp pwcal.conf $wcaldconfdir/pwcal.conf");
    chown($wcalduid, $wcaldgid, "$wcaldconfdir/pwcal.conf");
    chmod($wcaldmode, "$wcaldconfdir/pwcal.conf");
}

if (!-e "$wcaldconfdir/pwcal.pwd")
{
    print ("Copying pwcal.pwd\n");
    system("cp pwcal.pwd $wcaldconfdir/pwcal.pwd");
    chown($wcalduid, $wcaldgid, "$wcaldconfdir/pwcal.pwd");
    chmod($wcaldmode, "$wcaldconfdir/pwcal.pwd");
}

print ("Copying doc files\n");
if ( !-e "$wcaldhttpdir/doc/en/pwcal" )
{
    mkdir("$wcaldhttpdir/doc/en/pwcal", 0750);
}
system("cp doc/en/*.html $wcaldhttpdir/doc/en/pwcal");
system("chown -R $wcalduid $wcaldhttpdir/doc/en/pwcal");
system("chgrp -R $wcaldgid $wcaldhttpdir/doc/en/pwcal");
system("chmod -R 0750 $wcaldhttpdir/doc/en/pwcal");
if ( !-e "$wcaldhttpdir/doc/fr/pwcal" )
{
    mkdir("$wcaldhttpdir/doc/fr/pwcal", 0750);
}
system("cp doc/fr/*.html $wcaldhttpdir/doc/fr/pwcal");
system("chown -R $wcalduid $wcaldhttpdir/doc/fr/pwcal");
system("chgrp -R $wcaldgid $wcaldhttpdir/doc/fr/pwcal");
system("chmod -R 0750 $wcaldhttpdir/doc/fr/pwcal");

print ("\nP*Wcal successfully installed\n");
print ("Don't forget to fill the $wcaldconfdir/pwcal.pwd before running pwcald\n");
